@@ -143,7 +143,7 @@ mkpatch() {
 }
 spkg() {
   (mkpatch && \
-  if [ "${SIG}" -gt 0 ]; then name=${srcinstdir}/${src_patch_name} text="PATCH" sigfile; fi && \
+  if [ "${SIG:-0}" -gt 0 ]; then name=${srcinstdir}/${src_patch_name} text="PATCH" sigfile; fi && \
   cp ${src_orig_pkg} ${srcinstdir}/${src_orig_pkg_name} && \
   cp $0 ${srcinstdir}/`basename $0` && \
   if [ \( "${SIG}" \) -a \( -e $0.sig \) ]; then cp $0.sig ${srcinstdir}/; fi && \
